﻿/**
 * OEKOPOST HTTP-SOAP-Schnittstelle
 * C#.NET-Beispiel
 *
 * Die Datei "OekopostWebService.cs" wurde aus der OEKOPOST-WebService-WSDL-Datei
 * automatisch mit folgendem Kommando generiert:
 *     wsdl /l:cs /protocol:SOAP https://www.oekopost.de/soap/?wsdl
 */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace OEKOPOSTSoapExample
{
    public partial class FormMain : Form
    {
        private String UserName = "",
            PasswordHash = "",
            PasswordSalt = "";
        private OekopostWebService oekopost;

        public FormMain()
        {
            InitializeComponent();

            comboBoxLetterCountry.SelectedIndex = 0;
            comboBoxSMSType.SelectedIndex = 0;

            // Schnittstelle initialisieren
            oekopost = new OekopostWebService();
        }

        private void GetLoginInfo()
        {
            // Benutzername aus dem Textfeld lesen
            UserName = textUsername.Text;

            // Zufaelligen String als Salz generieren
            PasswordSalt = GenerateSalt();

            // Passwort-Hash generieren
            PasswordHash = MD5(MD5(textPassword.Text) + PasswordSalt);
        }

        private void buttonCheckLogin_Click(object sender, EventArgs e)
        {
            GetLoginInfo();

            // checkAccountLogin-Funktion der Schnittstelle aufrufen
            String result = oekopost.checkAccountLogin(UserName, PasswordHash, PasswordSalt);

            MessageBox.Show(result, "Ergebnis", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void buttonCheckBalance_Click(object sender, EventArgs e)
        {
            GetLoginInfo();

            // getAccountBalance-Funktion der Schnittstelle aufrufen
            String balanceCents;
            String result = oekopost.getAccountBalance(UserName, PasswordHash, PasswordSalt, out balanceCents);

            MessageBox.Show("Status: " + result + "\nGuthaben: " + (Convert.ToDouble(balanceCents) / 100).ToString() + " EUR",
                "Ergebnis",
                MessageBoxButtons.OK,
                MessageBoxIcon.Information);
        }

        private void buttonSubmitLetter_Click(object sender, EventArgs e)
        {
            GetLoginInfo();

            if (!System.IO.File.Exists(labelPDFFileName.Text))
            {
                MessageBox.Show("Bitte wählen Sie eine PDF-Datei aus.",
                    "Fehler",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Error);
                return;
            }

            // PDF-Datei einlesen
            byte[] data = System.IO.File.ReadAllBytes(labelPDFFileName.Text);

            // MD5-Hash der Datei generieren
            string dataHash = MD5(data);

            // submitPDFLetter-Funktion der Schnittstelle aufrufen
            string jobID, chargedCents;
            string result = oekopost.submitPDFLetter(UserName, PasswordHash, PasswordSalt,
                data, dataHash,
                "0", // Brief sofort senden
                checkBoxColor.Checked,
                checkBoxDuplex.Checked,
                radioButtonEnvelopeC5.Checked ? "C5" : "C6",
                comboBoxLetterCountry.Text,
                out jobID,
                out chargedCents);

            MessageBox.Show("Status: " + result + "\nAuftrags-Kennung: " + jobID + "\nAbgerechnet: " + (Convert.ToDouble(chargedCents) / 100).ToString() + " EUR",
                "Ergebnis",
                MessageBoxButtons.OK,
                MessageBoxIcon.Information);
        }

        private void buttonSubmitSMS_Click(object sender, EventArgs e)
        {
            GetLoginInfo();

            // submitSMS-Funktion der Schnittstelle aufrufen
            string jobID, chargedCents;
            string result = oekopost.submitSMS(UserName, PasswordHash, PasswordSalt,
                textSMSFrom.Text,
                textSMSTo.Text,
                textSMSText.Text,
                "0", // SMS sofort senden
                comboBoxSMSType.SelectedIndex.ToString(),
                out jobID,
                out chargedCents);

            MessageBox.Show("Status: " + result + "\nAuftrags-Kennung: " + jobID + "\nAbgerechnet: " + (Convert.ToDouble(chargedCents) / 100).ToString() + " EUR",
                "Ergebnis",
                MessageBoxButtons.OK,
                MessageBoxIcon.Information);
        }

        //
        // Hilfs-Funktionen
        //

        private String GenerateSalt()
        {
            Random rnd = new Random();
            StringBuilder strBuilder = new StringBuilder();

            for (int i = 0; i < 8; i++)
                strBuilder.Append(Convert.ToChar(Convert.ToInt32(Math.Floor(26 * rnd.NextDouble() + 65))));

            return (strBuilder.ToString());
        }

        private string MD5(string Str)
        {
            byte[] bytesToHash = Encoding.Default.GetBytes(Str);
            return (MD5(bytesToHash));
        }

        private string MD5(byte[] bytesToHash)
        {
            System.Security.Cryptography.MD5CryptoServiceProvider md5 = new System.Security.Cryptography.MD5CryptoServiceProvider();
            byte[] Hash = md5.ComputeHash(bytesToHash);
            return (BitConverter.ToString(Hash).Replace("-", "").ToLower());
        }

        private void buttonSelectPDFFile_Click(object sender, EventArgs e)
        {
            if (openFileDialog.ShowDialog() == DialogResult.OK)
                labelPDFFileName.Text = openFileDialog.FileName;
        }
    }
}
